@@ -1,5 +1,5 @@
 package App::Prove::Watch;
-$App::Prove::Watch::VERSION = '0.2';
+$App::Prove::Watch::VERSION = '0.3';
 
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ App::Prove::Watch - Run tests whenever changes occur.
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -72,11 +72,21 @@ sub new {
 	return bless {
 		watcher => $watcher,
 		prove   => $prove,
+		args    => $args,
 	}, $class;
 }
 
-sub prove   { return $_[0]->{prove}->() };
-sub watcher { return $_[0]->{watcher}   };
+sub prove   { return $_[0]->{prove}->() }
+sub watcher { 
+	my $self = shift;
+	
+	if (@_) {
+		$self->{watcher} = shift;
+	}
+	
+	return $self->{watcher};
+}
+
 
 sub run {
 	my ($self, $count) = @_;
@@ -87,9 +97,13 @@ sub run {
 	while ($count != 0) {
 		$self->watcher->wait(sub {
 			my $doit;
-			foreach my $event (@_) {
+			FILE: foreach my $event (@_) {
 				my $file = basename($event->{path});
-				next if $file =~ m/^(?:\.~)/;
+				next FILE if $file =~ m/^(?:\.[~#])/;
+				
+				if ($self->{args}{ignore}) {
+					next FILE if $file =~ $self->{args}{ignore};
+				}
 				
 				$doit++;
 				
@@ -111,7 +125,7 @@ sub _split_args {
 	
 	while (@args) {
 		local $_ = shift @args;
-		if ($_ eq '--watch' || $_ eq '--run') {
+		if ($_ eq '--watch' || $_ eq '--run' || $_ eq '--ignore') {
 			push(@ours, $_, shift @args);
 		}
 		else {
@@ -123,11 +137,17 @@ sub _split_args {
 	GetOptionsFromArray(\@ours, \%ours,
 		'watch=s@',
 		'run=s',
+		'ignore=s@',
 	);
 	
 	if (!$ours{watch} || !@{$ours{watch}}) {
 		$ours{watch} = ['.']
-	}	
+	}
+	
+	if ($ours{ignore}) {
+		my $merged = join('|', map { qr/$_/ } @{$ours{ignore}});
+		$ours{ignore} = qr/$merged/;
+	}
 	
 	return (\%ours, \@theirs);
 }
